<?php

namespace Drupal\bug_tracker\Entity\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Routing\UrlGeneratorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\file\Entity\File;
use Drupal\Core\Url;
use Drupal\Component\Render\FormattableMarkup;


/**
 * Provides a list controller for bug_report entity.
 */
class BugReportListBuilder extends EntityListBuilder {

  /**
   * The url generator.
   *
   * @var \Drupal\Core\Routing\UrlGeneratorInterface
   */
  protected $urlGenerator;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity.manager')->getStorage($entity_type->id()),
      $container->get('url_generator')
    );
  }

  /**
   * Constructs a new BugReport object.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   * @param \Drupal\Core\Entity\EntityStorageInterface $storage
   *   The entity storage class.
   * @param \Drupal\Core\Routing\UrlGeneratorInterface $url_generator
   *   The url generator.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, UrlGeneratorInterface $url_generator) {
    parent::__construct($entity_type, $storage);
    $this->urlGenerator = $url_generator;
  }

  /**
   * {@inheritdoc}
   *
   * We override ::render() so that we can add our own content above the table.
   * parent::render() is where EntityListBuilder creates the table using our
   * buildHeader() and buildRow() implementations.
   */
  public function render() {
    $build['table'] = parent::render();
    return $build;
  }

  /**
   * {@inheritdoc}
   *
   * Building the header and content lines for the contact list.
   *
   * Calling the parent::buildHeader() adds a column for the possible actions
   * and inserts the 'edit' and 'delete' links as defined for the entity type.
   */
  public function buildHeader() {
    $header['id'] = $this->t('Bug report #');
    $header['title'] = $this->t('title');
    $header['screenshot'] = $this->t('Screenshot');
    // status
    // priority
    // page url
    //
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\bug_tracker\Entity\BugReport */
    $row['id'] = $entity->id();
    $row['title'] = $entity->getTitle();
    $row['screenshot'] = array('data' => new FormattableMarkup($this->getFileLink($entity->getFileId()), array()));
    return $row + parent::buildRow($entity);
  }

  /**
   * Return link to file.
   */
  public function getFileLink($fid) {
    $file_object = File::load($fid);
    $file_name = $file_object ? $file_object->getFilename() : '';
    $file_url = $file_name ? Url::fromUri(file_create_url($file_object->getFileUri()))->toString() : '';
    $link = $file_url ? "<a href='{$file_url}' target='_blank'>{$file_name}</a>" : '';
    return $link;
  }

}
